powered by
Loads information on electric energy access at the municipality level in the Amazon region
load_iema(dataset = "iema", raw_data = FALSE, language = "eng")
A tibble.
tibble
A dataset name ("iema")
A boolean setting the return of raw (TRUE) or processed (FALSE) data.
boolean
TRUE
FALSE
A string that indicates in which language the data will be returned. Portuguese ("pt") and English ("eng") are supported.
string
if (FALSE) { # Download treated data data <- load_iema(raw_data = FALSE) }
Run the code above in your browser using DataLab