Loads information on gross domestic product at current prices, taxes, net of subsidies, on products at current prices and gross value added at current prices, total and by economic activity, and respective shares.
if (FALSE) {
# download treated municipal GDP data at the state level for 2010 to 2012data <- load_pibmunic(
raw_data = FALSE,
geo_level = "state",
time_period = 2010:2012)
}