powered by
Loads information the mines being explored legally in Brazil, including their location, status, product being mined and area in square meters.
load_sigmine(dataset = "sigmine_active", raw_data = FALSE, language = "eng")
A tibble.
tibble
A dataset name ("sigmine_active")
A boolean setting the return of raw (TRUE) or processed (FALSE) data.
boolean
TRUE
FALSE
A string that indicates in which language the data will be returned. Portuguese ("pt") and English ("eng") are supported.
string
if (FALSE) { # Download treated data (raw_data = FALSE) in portuguese (language = "pt"). data <- load_sigmine( dataset = "sigmine_active", raw_data = FALSE, language = "pt" ) }
Run the code above in your browser using DataLab