Loads information on agricultural establishments and activities
load_censoagro(
dataset,
raw_data = FALSE,
geo_level,
time_period,
language = "eng"
)A tibble.
A dataset name ("agricultural_land_area", "agricultural_area_use", "agricultural_employees_tractors", "agricultural_producer_condition", "animal_species", "animal_products", "vegetable_production_area", "vegetable_production_permanent", "vegetable_production_temporary", "livestock_production").
A boolean setting the return of raw (TRUE) or processed (FALSE) data.
A string that defines the geographic level of the data. Can be of "country" or "state".
For dataset "livestock_production", can be one of "country", "state", or "municipality"
A numeric indicating for which years the data will be loaded, in the format YYYY. Can be any vector of numbers, such as 2010:2012.
A string that indicates in which language the data will be returned. Portuguese ("pt") and English ("eng") are supported.